==> fastapi-0.1.6.tar.gz: fastapi-0.1.6/fastapi/openapi/docs.py <==
from starlette.responses import HTMLResponse


def get_swagger_ui_html(*, openapi_url: str, title: str) -> HTMLResponse:
    return HTMLResponse(
        """
    <! doctype html>
    <html>
    <head>
    <link type="text/css" rel="stylesheet" href="//unpkg.com/swagger-ui-dist@3/swagger-ui.css">
    <title>
    """
        + title
        + """
    </title>
    </head>
    <body>
    <div id="swagger-ui">
    </div>
    <script src="//unpkg.com/swagger-ui-dist@3/swagger-ui-bundle.js"></script>
    <!-- `SwaggerUIBundle` is now available on the page -->
    <script>
            
    const ui = SwaggerUIBundle({
        url: '"""
        + openapi_url
        + """',
        dom_id: '#swagger-ui',
        presets: [
        SwaggerUIBundle.presets.apis,
        SwaggerUIBundle.SwaggerUIStandalonePreset
        ],
        layout: "BaseLayout"
 
    })
    </script>
    </body>
    </html>
    """
    )


def get_redoc_html(*, openapi_url: str, title: str) -> HTMLResponse:
    return HTMLResponse(
        """
    <!DOCTYPE html>
<html>
  <head>
    <title>
    """
        + title
        + """
    </title>
    <!-- needed for adaptive design -->
    <meta charset="utf-8"/>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link href="https://fonts.googleapis.com/css?family=Montserrat:300,400,700|Roboto:300,400,700" rel="stylesheet">

    <!--
    ReDoc doesn't change outer page styles
    -->
    <style>
      body {
        margin: 0;
        padding: 0;
      }
    </style>
  </head>
  <body>
    <redoc spec-url='"""
        + openapi_url
        + """'></redoc>
    <script src="https://cdn.jsdelivr.net/npm/redoc@next/bundles/redoc.standalone.js"> </script>
  </body>
</html>
    """
    )

==> fastapi-0.1.12.tar.gz: fastapi-0.1.12/fastapi/openapi/docs.py <==
from starlette.responses import HTMLResponse


def get_swagger_ui_html(*, openapi_url: str, title: str) -> HTMLResponse:
    return HTMLResponse(
        """
    <! doctype html>
    <html>
    <head>
    <link type="text/css" rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swagger-ui-dist@3/swagger-ui.css">
    <title>
    """
        + title
        + """
    </title>
    </head>
    <body>
    <div id="swagger-ui">
    </div>
    <script src="https://cdn.jsdelivr.net/npm/swagger-ui-dist@3/swagger-ui-bundle.js"></script>
    <!-- `SwaggerUIBundle` is now available on the page -->
    <script>
            
    const ui = SwaggerUIBundle({
        url: '"""
        + openapi_url
        + """',
        dom_id: '#swagger-ui',
        presets: [
        SwaggerUIBundle.presets.apis,
        SwaggerUIBundle.SwaggerUIStandalonePreset
        ],
        layout: "BaseLayout"
 
    })
    </script>
    </body>
    </html>
    """
    )


def get_redoc_html(*, openapi_url: str, title: str) -> HTMLResponse:
    return HTMLResponse(
        """
    <!DOCTYPE html>
<html>
  <head>
    <title>
    """
        + title
        + """
    </title>
    <!-- needed for adaptive design -->
    <meta charset="utf-8"/>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link href="https://fonts.googleapis.com/css?family=Montserrat:300,400,700|Roboto:300,400,700" rel="stylesheet">

    <!--
    ReDoc doesn't change outer page styles
    -->
    <style>
      body {
        margin: 0;
        padding: 0;
      }
    </style>
  </head>
  <body>
    <redoc spec-url='"""
        + openapi_url
        + """'></redoc>
    <script src="https://cdn.jsdelivr.net/npm/redoc@next/bundles/redoc.standalone.js"> </script>
  </body>
</html>
    """
    )
